@@ -70,18 +70,18 @@ class FieldBase(metaclass=ABCMeta):
         self._logger = logging.getLogger(self.__class__.__name__)
 
     def __init_subclass__(cls, **kwargs):  # @NoSelf
-        """ register all subclassess to reconstruct them later """
+        """register all subclassess to reconstruct them later"""
         super().__init_subclass__(**kwargs)
         cls._subclasses[cls.__name__] = cls
 
     @property
     def label(self) -> Optional[str]:
-        """str: the name of the field """
+        """str: the name of the field"""
         return self._label
 
     @label.setter
     def label(self, value: str = None):
-        """ set the new label of the field """
+        """set the new label of the field"""
         if value is None or isinstance(value, str):
             self._label = value
         else:
@@ -139,7 +139,7 @@ class FieldBase(metaclass=ABCMeta):
 
     @classmethod
     def _from_hdf_dataset(cls, dataset) -> "FieldBase":
-        """ construct a field by reading data from an hdf5 dataset """
+        """construct a field by reading data from an hdf5 dataset"""
         # copy attributes from hdf
         attributes = dict(dataset.attrs)
 
@@ -153,7 +153,7 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def grid(self) -> GridBase:
-        """ GridBase: The grid on which the field is defined """
+        """GridBase: The grid on which the field is defined"""
         return self._grid
 
     def to_file(self, filename: str, **kwargs):
@@ -190,7 +190,7 @@ class FieldBase(metaclass=ABCMeta):
             raise ValueError(f"Do not know how to save data to `*{extension}`")
 
     def _write_hdf_dataset(self, hdf_path, key: str = "data"):
-        """ write data to a given hdf5 path `hdf_path` """
+        """write data to a given hdf5 path `hdf_path`"""
         # write the data
         dataset = hdf_path.create_dataset(key, data=self.data)
 
@@ -235,7 +235,7 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def data(self) -> np.ndarray:
-        """ :class:`~numpy.ndarray`: discretized data at the support points """
+        """:class:`~numpy.ndarray`: discretized data at the support points"""
         return self._data
 
     @data.setter
@@ -251,18 +251,18 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def dtype(self):
-        """ returns the numpy dtype of the underlying data """
+        """returns the numpy dtype of the underlying data"""
         # this property is necessary to support np.iscomplexobj for DataFieldBases
         return self.data.dtype
 
     @property
     def is_complex(self) -> bool:
-        """ bool: whether the field contains real or complex data """
+        """bool: whether the field contains real or complex data"""
         return np.iscomplexobj(self.data)  # type: ignore
 
     @property
     def attributes(self) -> Dict[str, Any]:
-        """ dict: describes the state of the instance (without the data) """
+        """dict: describes the state of the instance (without the data)"""
         return {
             "class": self.__class__.__name__,
             "grid": self.grid,
@@ -271,7 +271,7 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def attributes_serialized(self) -> Dict[str, str]:
-        """ dict: serialized version of the attributes """
+        """dict: serialized version of the attributes"""
         results = {}
         for key, value in self.attributes.items():
             if key == "grid":
@@ -302,13 +302,13 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def _data_flat(self):
-        """ :class:`~numpy.ndarray`: flat version of discretized data """
+        """:class:`~numpy.ndarray`: flat version of discretized data"""
         # flatten the first dimension of the internal data
         return self._data.reshape(-1, *self.grid.shape)
 
     @_data_flat.setter
     def _data_flat(self, value):
-        """ set the data from a value from a collection """
+        """set the data from a value from a collection"""
         if self.readonly:
             raise RuntimeError(f"Cannot write to {self.__class__.__name__}")
         # simply set the data -> this might need to be overwritten
@@ -316,26 +316,26 @@ class FieldBase(metaclass=ABCMeta):
 
     @property
     def real(self: TField) -> TField:
-        """:class:`FieldBase`: Real part of the field """
+        """:class:`FieldBase`: Real part of the field"""
         return self.copy(data=self.data.real)
 
     @property
     def imag(self: TField) -> TField:
-        """:class:`FieldBase`: Imaginary part of the field """
+        """:class:`FieldBase`: Imaginary part of the field"""
         return self.copy(data=self.data.imag)
 
     def conjugate(self: TField) -> TField:
-        """ returns complex conjugate of the field """
+        """returns complex conjugate of the field"""
         return self.copy(data=self.data.conj())
 
     def __eq__(self, other):
-        """ test fields for equality, ignoring the label """
+        """test fields for equality, ignoring the label"""
         if not isinstance(other, self.__class__):
             return NotImplemented
         return self.grid == other.grid and np.array_equal(self.data, other.data)
 
     def __neg__(self):
-        """ return the negative of the current field """
+        """return the negative of the current field"""
         return self.copy(data=-self.data)
 
     def _binary_operation(
@@ -422,55 +422,55 @@ class FieldBase(metaclass=ABCMeta):
         return self
 
     def __add__(self, other) -> "FieldBase":
-        """ add two fields """
+        """add two fields"""
         return self._binary_operation(other, operator.add, scalar_second=False)
 
     __radd__ = __add__
 
     def __iadd__(self: TField, other) -> TField:
-        """ add `other` to the current field """
+        """add `other` to the current field"""
         return self._binary_operation_inplace(other, operator.iadd, scalar_second=False)
 
     def __sub__(self, other) -> "FieldBase":
-        """ subtract two fields """
+        """subtract two fields"""
         return self._binary_operation(other, operator.sub, scalar_second=False)
 
     def __rsub__(self, other) -> "FieldBase":
-        """ subtract two fields """
+        """subtract two fields"""
         return self._binary_operation(other, lambda x, y: y - x, scalar_second=False)
 
     def __isub__(self: TField, other) -> TField:
-        """ add `other` to the current field """
+        """add `other` to the current field"""
         return self._binary_operation_inplace(other, operator.isub, scalar_second=False)
 
     def __mul__(self, other) -> "FieldBase":
-        """ multiply field by value """
+        """multiply field by value"""
         return self._binary_operation(other, operator.mul, scalar_second=False)
 
     __rmul__ = __mul__
 
     def __imul__(self: TField, other) -> TField:
-        """ multiply field by value """
+        """multiply field by value"""
         return self._binary_operation_inplace(other, operator.imul, scalar_second=False)
 
     def __truediv__(self, other) -> "FieldBase":
-        """ divide field by value """
+        """divide field by value"""
         return self._binary_operation(other, operator.truediv, scalar_second=True)
 
     def __itruediv__(self: TField, other) -> TField:
-        """ divide field by value """
+        """divide field by value"""
         return self._binary_operation_inplace(
             other, operator.itruediv, scalar_second=True
         )
 
     def __pow__(self, exponent: float) -> "FieldBase":
-        """ raise data of the field to a certain power """
+        """raise data of the field to a certain power"""
         if not np.isscalar(exponent):
             raise NotImplementedError("Only scalar exponents are supported")
         return self.copy(data=self.data ** exponent)
 
     def __ipow__(self: TField, exponent: float) -> TField:
-        """ raise data of the field to a certain power in-place """
+        """raise data of the field to a certain power in-place"""
         if self.readonly:
             raise RuntimeError(f"Cannot write to {self.__class__.__name__}")
 
@@ -618,7 +618,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         super().__init__(grid, data=data, label=label)
 
     def __repr__(self) -> str:
-        """ return instance as string """
+        """return instance as string"""
         class_name = self.__class__.__name__
         result = f"{class_name}(grid={self.grid!r}, data={self.data}"
         if self.label:
@@ -626,7 +626,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         return result + ")"
 
     def __str__(self) -> str:
-        """ return instance as string """
+        """return instance as string"""
         result = (
             f"{self.__class__.__name__}(grid={self.grid}, "
             f"data=Array{self.data.shape}"
@@ -642,7 +642,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         vmin: float = 0,
         vmax: float = 1,
         label: Optional[str] = None,
-        seed: Optional[int] = None,
+        rng: np.random.Generator = None,
     ):
         """create field with uniform distributed random values
 
@@ -657,14 +657,14 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 Largest random value
             label (str, optional):
                 Name of the field
-            seed (int, optional):
-                Seed of the random number generator. If `None`, the current
-                state is not changed.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
         """
+        if rng is None:
+            rng = np.random.default_rng()
+
         shape = (grid.dim,) * cls.rank + grid.shape
-        if seed is not None:
-            np.random.seed(seed)
-        data = np.random.uniform(vmin, vmax, shape)
+        data = rng.uniform(vmin, vmax, size=shape)
         return cls(grid, data, label=label)
 
     @classmethod
@@ -675,7 +675,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         std: float = 1,
         scaling: str = "physical",
         label: Optional[str] = None,
-        seed: Optional[int] = None,
+        rng: np.random.Generator = None,
     ):
         """create field with normal distributed random values
 
@@ -697,12 +697,11 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 larger volumes).
             label (str, optional):
                 Name of the field
-            seed (int, optional):
-                Seed of the random number generator. If `None`, the current
-                state is not changed.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
         """
-        if seed is not None:
-            np.random.seed(seed)
+        if rng is None:
+            rng = np.random.default_rng()
 
         if scaling == "none":
             noise_scale = std
@@ -712,7 +711,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             raise ValueError(f"Unknown noise scaling {scaling}")
 
         shape = (grid.dim,) * cls.rank + grid.shape
-        data = mean + noise_scale * np.random.randn(*shape)
+        data = mean + noise_scale * rng.normal(size=shape)
         return cls(grid, data, label=label)
 
     @classmethod
@@ -723,7 +722,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         harmonic=np.cos,
         axis_combination=np.multiply,
         label: Optional[str] = None,
-        seed: Optional[int] = None,
+        rng: np.random.Generator = None,
     ):
         r"""create a random field build from harmonics
 
@@ -762,13 +761,13 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 respectively.
             label (str, optional):
                 Name of the field
-            seed (int, optional):
-                Seed of the random number generator. If `None`, the current
-                state is not changed.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
         """
+        if rng is None:
+            rng = np.random.default_rng()
+
         tensor_shape = (grid.dim,) * cls.rank
-        if seed is not None:
-            np.random.seed(seed)
 
         data = np.empty(tensor_shape + grid.shape)
         # determine random field for each component
@@ -777,7 +776,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
             # random harmonic function along each axis
             for i in range(len(grid.axes)):
                 # choose wave vectors
-                ampl = np.random.random(modes)  # amplitudes
+                ampl = rng.random(size=modes)  # amplitudes
                 x = discretize_interval(0, 2 * np.pi, grid.shape[i])[0]
                 data_axis.append(
                     sum(a * harmonic(n * x) for n, a in enumerate(ampl, 1))
@@ -794,7 +793,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         exponent: float = 0,
         scale: float = 1,
         label: Optional[str] = None,
-        seed: Optional[int] = None,
+        rng: np.random.Generator = None,
     ):
         r"""create a field of random values with colored noise
 
@@ -818,18 +817,14 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
                 Scaling factor :math:`\Gamma` determining noise strength
             label (str, optional):
                 Name of the field
-            seed (int, optional):
-                Seed of the random number generator. If `None`, the current
-                state is not changed.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
         """
-        if seed is not None:
-            np.random.seed(seed)
-
-        # create function making colored noise
+        # get function making colored noise
         from ..tools.spectral import make_colored_noise
 
         make_noise = make_colored_noise(
-            grid.shape, dx=grid.discretization, exponent=exponent, scale=scale
+            grid.shape, dx=grid.discretization, exponent=exponent, scale=scale, rng=rng
         )
 
         # create random fields for each tensor component
@@ -888,7 +883,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
     @property
     def data_shape(self) -> Tuple[int, ...]:
-        """ tuple: the shape of the data at each grid point """
+        """tuple: the shape of the data at each grid point"""
         return (self.grid.dim,) * self.rank
 
     @classmethod
@@ -1000,7 +995,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
 
         # introduce wrapper function to process arrays
         def interpolator(point: np.ndarray, **kwargs) -> NumberOrArray:
-            """ return the interpolated value at the position `point` """
+            """return the interpolated value at the position `point`"""
             point = np.atleast_1d(point)
             # apply periodic boundary conditions to grid point
             point = self.grid.normalize_point(point, reflect=False)
@@ -1248,7 +1243,7 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         return self.__class__(grid, data, label=label)
 
     def add_interpolated(self, point: np.ndarray, amount: ArrayLike) -> None:
-        """ deprecated alias of method `insert` """
+        """deprecated alias of method `insert`"""
         # this was deprecated on 2021-02-23
         warnings.warn(
             "`add_interpolated` is deprecated. Use `insert` instead",
@@ -1278,19 +1273,24 @@ class DataFieldBase(FieldBase, metaclass=ABCMeta):
         if point.size != grid_dim or point.ndim != 1:
             raise DimensionError(f"Dimension mismatch for point {point}")
 
-        point = grid.normalize_point(point, reflect=False)
-
+        # determine the grid coordinates next to the chosen points
         low = np.array(grid.axes_bounds)[:, 0]
         c_l, d_l = np.divmod((point - low) / grid.discretization - 0.5, 1.0)
-        c_l = c_l.astype(np.intc)
+        c_l = c_l.astype(np.intc)  # support points to the left of the chosen points
         w_l = 1 - d_l  # weights of the low point
         w_h = d_l  # weights of the high point
 
-        # determine the total weight in first iteration
+        # apply periodic boundary conditions to grid coordinates
+        c_h = c_l + 1  # support points to the right of the chosen points
+        for ax in np.flatnonzero(grid.periodic):
+            c_l[..., ax] %= grid.shape[ax]
+            c_h[..., ax] %= grid.shape[ax]
+
+        # determine the valid points and the total weight in first iteration
         total_weight = 0
         cells = []
         for i in np.ndindex(*((2,) * grid_dim)):
-            coords = np.choose(i, [c_l, c_l + 1])
+            coords = np.choose(i, [c_l, c_h])
             if np.all(coords >= 0) and np.all(coords < grid.shape):
                 weight = np.prod(np.choose(i, [w_l, w_h]))
                 total_weight += weight
