@@ -101,7 +101,7 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
 
     @property
     def state(self) -> Dict[str, Any]:
-        """ state: the state of the grid """
+        """state: the state of the grid"""
         radius = self.axes_bounds[0][1]
         return {
             "radius": radius,
@@ -131,17 +131,17 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
 
     @property
     def radius(self) -> float:
-        """ float: radius of the cylinder """
+        """float: radius of the cylinder"""
         return self.axes_bounds[0][1]
 
     @property
     def length(self) -> float:
-        """ float: length of the cylinder """
+        """float: length of the cylinder"""
         return self.axes_bounds[1][1] - self.axes_bounds[1][0]
 
     @property
     def volume(self) -> float:
-        """ float: total volume of the grid """
+        """float: total volume of the grid"""
         return float(np.pi * self.radius ** 2 * self.length)
 
     def get_random_point(
@@ -149,6 +149,7 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
         boundary_distance: float = 0,
         cartesian: bool = True,
         avoid_center: bool = False,
+        rng: np.random.Generator = None,
     ) -> np.ndarray:
         """return a random point within the grid
 
@@ -163,10 +164,15 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
             avoid_center (bool): Determines whether the boundary distance
                 should also be kept from the center, i.e., whether points close
                 to the center are returned.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
 
         Returns:
             :class:`~numpy.ndarray`: The coordinates of the point
         """
+        if rng is None:
+            rng = np.random.default_rng()
+
         # handle the boundary distance
         r_min = boundary_distance if avoid_center else 0
         r_mag = self.radius - boundary_distance - r_min
@@ -179,8 +185,8 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
                 raise RuntimeError("Random points would be too close to boundary")
 
         # create random point
-        r = r_mag * np.random.random() + r_min
-        z = z_min + (z_max - z_min) * np.random.random()
+        r = r_mag * rng.random() + r_min
+        z = z_min + (z_max - z_min) * rng.random()
         point = np.array([r, z])
         if cartesian:
             return self.point_to_cartesian(point)
@@ -297,7 +303,7 @@ class CylindricalSymGrid(GridBase):  # lgtm [py/missing-equals]
 
     @cached_property()
     def cell_volume_data(self) -> Tuple[np.ndarray, float]:
-        """ :class:`~numpy.ndarray`: the volumes of all cells """
+        """:class:`~numpy.ndarray`: the volumes of all cells"""
         dr, dz = self.discretization
         rs = np.arange(self.shape[0] + 1) * dr
         areas = np.pi * rs ** 2
@@ -541,7 +547,7 @@ class CylindricalGrid(CylindricalSymGrid):
     """
 
     def __init__(self, *args, **kwargs):
-        """ class deprecated since 2021-05-21 """
+        """class deprecated since 2021-05-21"""
         warnings.warn(
             "CylindricalGrid is a deprecated class. Use CylindricalSymGrid instead",
             DeprecationWarning,
