@@ -86,12 +86,12 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
 
     @property
     def state(self) -> Dict[str, Any]:
-        """ state: the state of the grid """
+        """state: the state of the grid"""
         return {"radius": self.radius, "shape": self.shape}
 
     @property
     def has_hole(self) -> bool:
-        """ returns whether the inner radius is larger than zero """
+        """returns whether the inner radius is larger than zero"""
         return self.axes_bounds[0][0] > 0
 
     @classmethod
@@ -110,7 +110,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
 
     @property
     def radius(self) -> Union[float, Tuple[float, float]]:
-        """ float: radius of the sphere """
+        """float: radius of the sphere"""
         r_inner, r_outer = self.axes_bounds[0]
         if r_inner == 0:
             return r_outer
@@ -119,7 +119,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
 
     @property
     def volume(self) -> float:
-        """ float: total volume of the grid """
+        """float: total volume of the grid"""
         r_inner, r_outer = self.axes_bounds[0]
         volume = volume_from_radius(r_outer, dim=self.dim)
         if r_inner > 0:
@@ -128,7 +128,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
 
     @cached_property()
     def cell_volume_data(self) -> Tuple[np.ndarray]:
-        """ tuple of :class:`~numpy.ndarray`: the volumes of all cells """
+        """tuple of :class:`~numpy.ndarray`: the volumes of all cells"""
         dr = self.discretization[0]
         rs = self.axes_coords[0]
         volumes_h = volume_from_radius(rs + 0.5 * dr, dim=self.dim)
@@ -154,6 +154,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
         boundary_distance: float = 0,
         cartesian: bool = True,
         avoid_center: bool = False,
+        rng: np.random.Generator = None,
     ) -> np.ndarray:
         """return a random point within the grid
 
@@ -168,10 +169,15 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
             avoid_center (bool): Determines whether the boundary distance
                 should also be kept from the center, i.e., whether points close
                 to the center are returned.
+            rng (:class:`~numpy.random.Generator`):
+                Random number generator (default: :func:`~numpy.random.default_rng()`)
 
         Returns:
             :class:`~numpy.ndarray`: The coordinates of the point
         """
+        if rng is None:
+            rng = np.random.default_rng()
+
         # handle the boundary distance
         r_inner, r_outer = self.axes_bounds[0]
         r_min = r_inner
@@ -183,7 +189,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
             raise RuntimeError("Random points would be too close to boundary")
 
         # create random point
-        r = np.array([r_mag * np.random.random() + r_min])
+        r = np.array([r_mag * rng.random() + r_min])
         if cartesian:
             return self.point_to_cartesian(r)
         else:
@@ -619,7 +625,7 @@ class PolarGrid(PolarSymGrid):
     """
 
     def __init__(self, *args, **kwargs):
-        """ class deprecated since 2021-05-21 """
+        """class deprecated since 2021-05-21"""
         warnings.warn(
             "PolarGrid is a deprecated class. Use PolarSymGrid instead",
             DeprecationWarning,
@@ -635,7 +641,7 @@ class SphericalGrid(SphericalSymGrid):
     """
 
     def __init__(self, *args, **kwargs):
-        """ class deprecated since 2021-05-21 """
+        """class deprecated since 2021-05-21"""
         warnings.warn(
             "PolarGrid is a deprecated class. Use SphericalSymGrid instead",
             DeprecationWarning,
